@@ -10,20 +10,21 @@
 #include <config-kleopatra.h>
 
 #include "decryptverifyfilescommand.h"
+#include "viewemailfilescommand.h"
 
-#include "fileoperationspreferences.h"
 #include "command_p.h"
+#include "fileoperationspreferences.h"
 
-#include "crypto/decryptverifyfilescontroller.h"
 #include "crypto/autodecryptverifyfilescontroller.h"
+#include "crypto/decryptverifyfilescontroller.h"
 
 #include <utils/filedialog.h>
 
+#include <Libkleo/Classify>
 #include <Libkleo/Stl_Util>
 
-#include <KLocalizedString>
 #include "kleopatra_debug.h"
-
+#include <KLocalizedString>
 
 #include <exception>
 
@@ -38,9 +39,9 @@ class DecryptVerifyFilesCommand::Private : public Command::Private
     {
         return static_cast<DecryptVerifyFilesCommand *>(q);
     }
+
 public:
-    explicit Private(DecryptVerifyFilesCommand *qq, KeyListController *c,
-                     bool forceManualMode=false);
+    explicit Private(DecryptVerifyFilesCommand *qq, KeyListController *c, bool forceManualMode = false);
     ~Private() override;
 
     QStringList selectFiles() const;
@@ -48,18 +49,29 @@ public:
     void init();
 
 private:
+    void finishIfEverythingIsDone()
+    {
+        if (files.empty() && emailFiles.empty()) {
+            finished();
+        }
+    }
+
     void slotControllerDone()
     {
-        finished();
+        files.clear();
+        finishIfEverythingIsDone();
     }
+
     void slotControllerError(int, const QString &msg)
     {
-        KMessageBox::error(parentWidgetOrView(), msg, i18n("Decrypt/Verify Failed"));
-        finished();
+        KMessageBox::error(parentWidgetOrView(), msg, i18nc("@title:window", "Decrypt/Verify Failed"));
+        files.clear();
+        finishIfEverythingIsDone();
     }
 
 private:
     QStringList files;
+    QStringList emailFiles;
     std::shared_ptr<const ExecutionContext> shared_qq;
     DecryptVerifyFilesController *mController;
 };
@@ -77,9 +89,9 @@ const DecryptVerifyFilesCommand::Private *DecryptVerifyFilesCommand::d_func() co
 #define q q_func()
 
 DecryptVerifyFilesCommand::Private::Private(DecryptVerifyFilesCommand *qq, KeyListController *c, bool forceManualMode)
-    : Command::Private(qq, c),
-      files(),
-      shared_qq(qq, [](DecryptVerifyFilesCommand*){})
+    : Command::Private(qq, c)
+    , files()
+    , shared_qq(qq, [](DecryptVerifyFilesCommand *) {})
 {
     FileOperationsPreferences prefs;
     if (!forceManualMode && prefs.autoDecryptVerify()) {
@@ -87,7 +99,6 @@ DecryptVerifyFilesCommand::Private::Private(DecryptVerifyFilesCommand *qq, KeyLi
     } else {
         mController = new DecryptVerifyFilesController();
     }
-
 }
 
 DecryptVerifyFilesCommand::Private::~Private()
@@ -125,8 +136,12 @@ DecryptVerifyFilesCommand::DecryptVerifyFilesCommand(const QStringList &files, Q
 void DecryptVerifyFilesCommand::Private::init()
 {
     mController->setExecutionContext(shared_qq);
-    connect(mController, &Controller::done, q, [this]() { slotControllerDone(); });
-    connect(mController, &Controller::error, q, [this](int err, const QString &details) { slotControllerError(err, details); });
+    connect(mController, &Controller::done, q, [this]() {
+        slotControllerDone();
+    });
+    connect(mController, &Controller::error, q, [this](int err, const QString &details) {
+        slotControllerError(err, details);
+    });
 }
 
 DecryptVerifyFilesCommand::~DecryptVerifyFilesCommand()
@@ -143,7 +158,8 @@ void DecryptVerifyFilesCommand::setOperation(DecryptVerifyOperation op)
 {
     try {
         d->mController->setOperation(op);
-    } catch (...) {}
+    } catch (...) {
+    }
 }
 
 DecryptVerifyOperation DecryptVerifyFilesCommand::operation() const
@@ -153,9 +169,7 @@ DecryptVerifyOperation DecryptVerifyFilesCommand::operation() const
 
 void DecryptVerifyFilesCommand::doStart()
 {
-
     try {
-
         if (d->files.empty()) {
             d->files = d->selectFiles();
         }
@@ -163,13 +177,33 @@ void DecryptVerifyFilesCommand::doStart()
             d->finished();
             return;
         }
+
+        for (const auto &file : std::as_const(d->files)) {
+            const unsigned int classification = classify(file);
+            if (classification & Class::MimeFile) {
+                d->emailFiles << file;
+                d->files.removeAll(file);
+            }
+        }
+
+        if (!d->emailFiles.empty()) {
+            const auto viewEmailCommand = new ViewEmailFilesCommand(d->emailFiles, nullptr);
+            connect(viewEmailCommand, &ViewEmailFilesCommand::finished, this, [this] {
+                d->emailFiles.clear();
+                d->finishIfEverythingIsDone();
+            });
+            viewEmailCommand->start();
+        }
+
+        if (d->files.empty()) {
+            return;
+        }
+
         d->mController->setFiles(d->files);
         d->mController->start();
 
     } catch (const std::exception &e) {
-        d->information(i18n("An error occurred: %1",
-                            QString::fromLocal8Bit(e.what())),
-                       i18n("Decrypt/Verify Files Error"));
+        d->information(i18n("An error occurred: %1", QString::fromLocal8Bit(e.what())), i18n("Decrypt/Verify Files Error"));
         d->finished();
     }
 }
