@@ -15,6 +15,7 @@
 
 #include "subkeyswidget.h"
 
+#include "commands/addadskcommand.h"
 #include "commands/addsubkeycommand.h"
 #include "commands/changeexpirycommand.h"
 #include "commands/exportsecretsubkeycommand.h"
@@ -24,7 +25,9 @@
 
 #include <kleopatra_debug.h>
 
+#include <Libkleo/Compat>
 #include <Libkleo/Formatting>
+#include <Libkleo/GnuPG>
 #include <Libkleo/KeyCache>
 #include <Libkleo/KeyHelpers>
 #include <Libkleo/TreeWidget>
@@ -42,9 +45,14 @@
 #include <QTreeWidgetItem>
 #include <QVBoxLayout>
 
+#include <QGpgME/CryptoConfig>
+#include <QGpgME/Protocol>
+
 #include <gpgme++/context.h>
 #include <gpgme++/key.h>
 
+#include <gpgme.h>
+
 Q_DECLARE_METATYPE(GpgME::Subkey)
 
 using namespace Kleo;
@@ -74,6 +82,18 @@ class SubKeysWidget::Private
     SubKeysWidget *const q;
 
 public:
+    enum Columns {
+        KeyId,
+        Fingerprint,
+        Status,
+        ValidFrom,
+        ValidUntil,
+        Usage,
+        Algorithm,
+        Storage,
+        Keygrip,
+    };
+
     Private(SubKeysWidget *qq)
         : q{qq}
         , ui{qq}
@@ -91,6 +111,11 @@ public:
             menu->addAction(ui.transferToSmartcardAction);
             menu->addAction(ui.exportSecretAction);
             menu->addAction(ui.restoreAction);
+#if GPGME_VERSION_NUMBER >= 0x011800 // 1.24.0
+            if (engineIsVersion(2, 4, 6) || (engineIsVersion(2, 2, 45) && !engineIsVersion(2, 3, 0))) {
+                menu->addAction(ui.addAdskAction);
+            }
+#endif
             menu->popup(ui.moreButton->mapToGlobal(QPoint()));
         });
     }
@@ -119,6 +144,7 @@ public:
         QAction *transferToSmartcardAction = nullptr;
         QAction *exportSecretAction = nullptr;
         QAction *addSubkeyAction = nullptr;
+        QAction *addAdskAction = nullptr;
 
         QAction *restoreAction = nullptr;
         QPushButton *restoreBtn = nullptr;
@@ -131,26 +157,23 @@ public:
         {
             mainLayout = new QVBoxLayout{widget};
             mainLayout->setContentsMargins({});
-            mainLayout->setSpacing(0);
 
             subkeysTree = new TreeWidget{widget};
             subkeysTree->setAccessibleName(i18nc("@label", "Subkeys"));
             subkeysTree->setRootIsDecorated(false);
             subkeysTree->setHeaderLabels({
-                i18nc("@title:column", "ID"),
+                i18nc("@title:column", "Key ID"),
                 i18nc("@title:column", "Fingerprint"),
+                i18nc("@title:column", "Status"),
                 i18nc("@title:column", "Valid From"),
                 i18nc("@title:column", "Valid Until"),
-                i18nc("@title:column", "Status"),
-                i18nc("@title:column", "Algorithm"),
                 i18nc("@title:column", "Usage"),
+                i18nc("@title:column", "Algorithm"),
                 i18nc("@title:column", "Storage"),
+                i18nc("@title:column", "Keygrip"),
             });
             mainLayout->addWidget(subkeysTree);
 
-            auto separator = new KSeparator(widget);
-            mainLayout->addWidget(separator);
-
             {
                 auto buttonRow = new QHBoxLayout;
 
@@ -160,6 +183,13 @@ public:
                 restoreAction = new QAction({}, i18nc("@action:button", "Restore printed backup"), widget);
                 transferToSmartcardAction = new QAction({}, i18nc("@action:button", "Transfer to smartcard"), widget);
                 exportSecretAction = new QAction({}, i18nc("@action:button", "Export secret subkey"), widget);
+                addAdskAction = new QAction({}, i18nc("@action:button", "Add ADSK"));
+                addAdskAction->setToolTip(i18nc("@info:tooltip",
+                                                "Add the ADSK specified in the GnuPG configuration to your certificate. By "
+                                                "adding an ADSK to your certificate, you allow the owner of the ADSK to decrypt all new messages that "
+                                                "are encrypted for your certificate, if the client encrypting the "
+                                                "message supports this functionality."));
+                addAdskAction->setVisible(false);
 
                 addActionButton(buttonRow, addSubkeyAction);
                 addActionButton(buttonRow, changeValidityAction);
@@ -339,6 +369,11 @@ SubKeysWidget::SubKeysWidget(QWidget *parent)
     connect(d->ui.addSubkeyAction, &QAction::triggered, this, [this]() {
         d->addSubkey();
     });
+    connect(d->ui.addAdskAction, &QAction::triggered, this, [this]() {
+        auto addADSKCommand = new Kleo::Commands::AddADSKCommand(key());
+        addADSKCommand->setParentWidget(this);
+        addADSKCommand->start();
+    });
 }
 
 SubKeysWidget::~SubKeysWidget() = default;
@@ -357,50 +392,52 @@ void SubKeysWidget::setKey(const GpgME::Key &key)
     const auto subkeys = key.subkeys();
     for (const auto &subkey : subkeys) {
         auto item = new QTreeWidgetItem;
-        item->setData(0, Qt::DisplayRole, Formatting::prettyID(subkey.keyID()));
-        item->setData(0, Qt::AccessibleTextRole, Formatting::accessibleHexID(subkey.keyID()));
-        item->setData(0, Qt::UserRole, QVariant::fromValue(subkey));
-        item->setData(1, Qt::DisplayRole, Formatting::prettyID(subkey.fingerprint()));
-        item->setData(1, Qt::AccessibleTextRole, Formatting::accessibleHexID(subkey.fingerprint()));
-        item->setData(2, Qt::DisplayRole, Kleo::Formatting::creationDateString(subkey));
-        item->setData(2, Qt::AccessibleTextRole, Formatting::accessibleCreationDate(subkey));
-        item->setData(3,
+        item->setData(Private::KeyId, Qt::DisplayRole, Formatting::prettyID(subkey.keyID()));
+        item->setData(Private::KeyId, Qt::AccessibleTextRole, Formatting::accessibleHexID(subkey.keyID()));
+        item->setData(Private::KeyId, Qt::UserRole, QVariant::fromValue(subkey));
+        item->setData(Private::Fingerprint, Qt::DisplayRole, Formatting::prettyID(subkey.fingerprint()));
+        item->setData(Private::Fingerprint, Qt::AccessibleTextRole, Formatting::accessibleHexID(subkey.fingerprint()));
+        item->setData(Private::Status, Qt::DisplayRole, Kleo::Formatting::validityShort(subkey));
+        item->setData(Private::ValidFrom, Qt::DisplayRole, Kleo::Formatting::creationDateString(subkey));
+        item->setData(Private::ValidFrom, Qt::AccessibleTextRole, Formatting::accessibleCreationDate(subkey));
+        item->setData(Private::ValidUntil,
                       Qt::DisplayRole,
                       subkey.neverExpires() ? Kleo::Formatting::expirationDateString(subkey.parent()) : Kleo::Formatting::expirationDateString(subkey));
-        item->setData(3,
+        item->setData(Private::ValidUntil,
                       Qt::AccessibleTextRole,
                       subkey.neverExpires() ? Kleo::Formatting::accessibleExpirationDate(subkey.parent()) : Kleo::Formatting::accessibleExpirationDate(subkey));
-        item->setData(4, Qt::DisplayRole, Kleo::Formatting::validityShort(subkey));
-        item->setData(5, Qt::DisplayRole, Kleo::Formatting::prettyAlgorithmName(subkey.algoName()));
-        item->setData(6, Qt::DisplayRole, Kleo::Formatting::usageString(subkey));
+        item->setData(Private::Usage, Qt::DisplayRole, Kleo::Formatting::usageString(subkey));
+        item->setData(Private::Algorithm, Qt::DisplayRole, Kleo::Formatting::prettyAlgorithmName(subkey.algoName()));
         const auto isPrimary = subkey.keyID() == key.keyID();
         if (!key.hasSecret()) {
-            item->setData(7, Qt::DisplayRole, i18nc("not applicable", "n/a"));
+            item->setData(Private::Storage, Qt::DisplayRole, i18nc("not applicable", "n/a"));
         } else if (subkey.isCardKey()) {
             if (const char *serialNo = subkey.cardSerialNumber()) {
-                item->setData(7, Qt::DisplayRole, i18nc("smart card <serial number>", "smart card %1", QString::fromUtf8(serialNo)));
+                item->setData(Private::Storage, Qt::DisplayRole, i18nc("smart card <serial number>", "smart card %1", QString::fromUtf8(serialNo)));
             } else {
-                item->setData(7, Qt::DisplayRole, i18n("smart card"));
+                item->setData(Private::Storage, Qt::DisplayRole, i18n("smart card"));
             }
         } else if (isPrimary && key.hasSecret() && !subkey.isSecret()) {
-            item->setData(7, Qt::DisplayRole, i18nc("key is 'offline key', i.e. secret key is not stored on this computer", "offline"));
+            item->setData(Private::Storage, Qt::DisplayRole, i18nc("key is 'offline key', i.e. secret key is not stored on this computer", "offline"));
         } else if (subkey.isSecret()) {
-            item->setData(7, Qt::DisplayRole, i18n("on this computer"));
+            item->setData(Private::Storage, Qt::DisplayRole, i18n("on this computer"));
         } else {
-            item->setData(7, Qt::DisplayRole, i18nc("unknown storage location", "unknown"));
+            item->setData(Private::Storage, Qt::DisplayRole, i18nc("unknown storage location", "unknown"));
         }
+        item->setData(Private::Keygrip, Qt::DisplayRole, QString::fromLatin1(subkey.keyGrip()));
         d->ui.subkeysTree->addTopLevelItem(item);
         if (subkey.fingerprint() == selectedKeyFingerprint) {
             d->ui.subkeysTree->setCurrentItem(item);
         }
     }
-    d->ui.subkeysTree->header()->resizeSections(QHeaderView::ResizeToContents);
 
     d->ui.changeValidityAction->setVisible(key.hasSecret());
     d->ui.exportSecretAction->setVisible(key.hasSecret());
     d->ui.transferToSmartcardAction->setVisible(key.hasSecret());
     d->ui.addSubkeyAction->setVisible(key.hasSecret());
     d->ui.restoreAction->setVisible(true);
+    const auto adskConfig = getCryptoConfigEntry(QGpgME::cryptoConfig(), "gpg", "default-new-key-adsk");
+    d->ui.addAdskAction->setVisible(key.protocol() == GpgME::OpenPGP && key.hasSecret() && adskConfig && adskConfig->isSet());
 
     d->ui.exportOpenSSHAction->setEnabled(false);
     d->ui.exportOpenSSHBtn->setVisible(!key.hasSecret());
@@ -411,11 +448,10 @@ void SubKeysWidget::setKey(const GpgME::Key &key)
     d->updateState();
 
     if (!d->ui.subkeysTree->restoreColumnLayout(QStringLiteral("SubkeysWidget"))) {
-        d->ui.subkeysTree->hideColumn(1);
-    }
-    for (int i = 0; i < d->ui.subkeysTree->columnCount(); i++) {
-        d->ui.subkeysTree->resizeColumnToContents(i);
+        d->ui.subkeysTree->hideColumn(Private::KeyId);
+        d->ui.subkeysTree->hideColumn(Private::Keygrip);
     }
+    d->ui.subkeysTree->resizeToContentsLimited();
 }
 
 GpgME::Key SubKeysWidget::key() const
