@@ -33,11 +33,10 @@ private:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
     Q_PRIVATE_SLOT(d, void slotSelectedCertificates(int, QByteArray))
     Q_PRIVATE_SLOT(d, void slotDialogAccepted())
     Q_PRIVATE_SLOT(d, void slotDialogRejected())
 };
 
 }
-
